# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-01-03 07:07
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('preferences', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='MyPreferences',
            fields=[
                ('preferences_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='preferences.Preferences')),
                ('portal_contact_email', models.EmailField(max_length=254)),
            ],
            bases=('preferences.preferences',),
        ),
    ]
